==> giga_auto-0.1.1-py3-none-any.whl: giga_auto/request.py <==
from typing import Union

import requests

from giga_auto.logger import log

DEFAULT_TIMEOUT = 60


class RequestBase(object):

    def __init__(self, base_url: str = '', business: str = ''):
        """
        :param base_url: The base URL of the API
        """
        self.base_url = base_url.rstrip('/')
        self._session = requests.Session()
        self._session.timeout = DEFAULT_TIMEOUT
        self.business = business
        self.expect_code = 200

    def business_code(self):
        match = {
            'drp': '0000',
            'wms': '0000',
            'onsite': 1000
        }
        if self.business in match:
            self.expect_code = match[self.business]


    @log
    def _request(self, method, url, **kwargs):
        self.business_code()
        response = None
        if not url.startswith('http'):
            url = f'{self.base_url}{url}' if 'route' in self.base_url else f'{self.base_url}/{url.lstrip("/")}'
        try:
            response = self._session.request(method.upper(), url, **kwargs)
            response.raise_for_status()
            return response
        except requests.RequestException as e:
            if response:
                raise Exception(f"HTTP request failed with error: {e}\n response: {response.text}")
            raise e

    # @log
    def request(self, method, url, **kwargs) -> Union[dict, list, str]:
        response = self._request(method, url, **kwargs)
        try:
            response = response.json()
        except ValueError as e:
            raise Exception(f"Response body is not a JSON: {response.text}, error: {e}")
        if 'code' in response:
            if response['code'] != self.expect_code:
                print(f"url: {url} \n response_body: {response}")
                raise Exception(f"Response error: {response}")
        if 'error' in response:
            if response['error'] != 0:
                print(f"url: {url} \n response_body: {response}")
        return response

    def get(self, url, **kwargs) -> Union[dict, list, str]:
        return self.request('GET', url, **kwargs)

    def post(self, url, **kwargs) -> Union[dict, list, str]:
        return self.request('POST', url, **kwargs)

    def put(self, url, **kwargs) -> Union[dict, list, str]:
        return self.request('PUT', url, **kwargs)

==> giga_auto-0.1.8-py3-none-any.whl: giga_auto/request.py <==
from typing import Union

import requests

from giga_auto.logger import log

DEFAULT_TIMEOUT = 60


class RequestBase(object):

    def __init__(self, base_url: str = '',  expect_code: int = 200):
        """
        :param base_url: The base URL of the API
        """
        self.base_url = base_url.rstrip('/')
        self._session = requests.Session()
        self._session.timeout = DEFAULT_TIMEOUT
        self.expect_code = expect_code

    @log
    def _request(self, method, url, **kwargs):
        response = None
        if not url.startswith('http'):
            url = f'{self.base_url}{url}' if 'route' in self.base_url else f'{self.base_url}/{url.lstrip("/")}'
        try:
            response = self._session.request(method.upper(), url, **kwargs)
            response.raise_for_status()
            return response
        except requests.RequestException as e:
            if response:
                raise Exception(f"HTTP request failed with error: {e}\n response: {response.text}")
            raise e

    # @log
    def request(self, method, url, **kwargs) -> Union[dict, list, str]:
        response = self._request(method, url, **kwargs)
        try:
            response = response.json()
        except ValueError as e:
            raise Exception(f"Response body is not a JSON: {response.text}, error: {e}")
        if 'code' in response:
            if response['code'] != self.expect_code:
                print(f"url: {url} \n response_body: {response}")
                raise Exception(f"Response error: {response}")
        if 'error' in response:
            if response['error'] != 0:
                print(f"url: {url} \n response_body: {response}")
        return response

    def get(self, url, **kwargs) -> Union[dict, list, str]:
        return self.request('GET', url, **kwargs)

    def post(self, url, **kwargs) -> Union[dict, list, str]:
        return self.request('POST', url, **kwargs)

    def put(self, url, **kwargs) -> Union[dict, list, str]:
        return self.request('PUT', url, **kwargs)
